<?php

namespace App\Gateway;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Session;

class Zarinpal
{
    public static function redirect_if_payment_success()
    {
        if (Session::has('call_back')) {
            return url(Session::get('call_back')['success']);
        }
    }

    public static function redirect_if_payment_faild()
    {
        if (Session::has('call_back')) {
            return url(Session::get('call_back')['fail']);
        }
    }

    public function view()
    {
        abort(404); // چون در زرین‌پال صفحه واسط نداریم، نیاز به View نیست
    }

    public static function fallback()
    {
        return url('/payment/zarinpal');
    }

    public static function make_payment($array)
    {
        $merchant_id = $array['merchant_id'];
        $amount = $array['pay_amount'] * 10; // تبدیل تومان به ریال
        $callback = self::fallback();
        $billName = $array['billName'];

        $response = Http::post('https://api.zarinpal.com/pg/v4/payment/request.json', [
            'merchant_id' => $merchant_id,
            'amount' => $amount,
            'callback_url' => $callback,
            'description' => $billName ?? 'پرداخت فاکتور',
        ]);

        $res = $response->json();

        if (isset($res['data']['code']) && $res['data']['code'] == 100) {
            $authority = $res['data']['authority'];

            $data = [
                'payment_mode' => 'zarinpal',
                'merchant_id' => $merchant_id,
                'amount' => $amount,
                'main_amount' => $array['amount'],
                'charge' => $array['charge'],
                'getway_id' => $array['getway_id'],
                'email' => $array['email'] ?? null,
                'name' => $array['name'] ?? null,
                'currency' => $array['currency'],
                'authority' => $authority,
                'payment_type' => $array['payment_type'] ?? '',
                'is_fallback' => $array['is_fallback'] ?? 0,
            ];

            Session::put('zarinpal_credentials', $data);
            return redirect('https://www.zarinpal.com/pg/StartPay/' . $authority);
        }

        return redirect(self::redirect_if_payment_faild());
    }

    public function status(Request $request)
    {
        if (!Session::has('zarinpal_credentials')) {
            return abort(404);
        }

        $info = Session::get('zarinpal_credentials');
        $authority = $request->get('Authority');
        $merchant_id = $info['merchant_id'];
        $amount = $info['amount'];

        $response = Http::post('https://api.zarinpal.com/pg/v4/payment/verify.json', [
            'merchant_id' => $merchant_id,
            'amount' => $amount,
            'authority' => $authority,
        ]);

        $res = $response->json();

        if (isset($res['data']['code']) && $res['data']['code'] == 100) {
            $data = [
                'payment_id' => $res['data']['ref_id'],
                'payment_method' => 'zarinpal',
                'getway_id' => $info['getway_id'],
                'payment_type' => $info['payment_type'],
                'amount' => $info['main_amount'],
                'charge' => $info['charge'],
                'status' => 1,
                'payment_status' => 1,
                'is_fallback' => $info['is_fallback'],
            ];

            Session::put('payment_info', $data);
            Session::forget('zarinpal_credentials');
            return redirect(self::redirect_if_payment_success());
        }

        Session::forget('zarinpal_credentials');
        return redirect(self::redirect_if_payment_faild());
    }

    public function fail()
    {
        $data['payment_status'] = 0;
        Session::put('payment_info', $data);
        Session::forget('zarinpal_credentials');
        return redirect(self::redirect_if_payment_faild());
    }

    public static function isfraud($creds)
    {
        // اختیاری: بررسی صحت تراکنش مجدد
        return 1;
    }
}
