<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\User;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;
use Spatie\Permission\Models\Role;
use Spatie\Permission\Models\Permission;

class AdminController extends Controller
{
    public function __construct()
    {
        $this->middleware('permission:admin');
    }

    /**
     * نمایش لیست ادمین‌ها
     */
    public function index()
    {
        $users = User::where('role', 'admin')->where('id', '!=', 1)->latest()->get();
        return view('admin.admin.index', compact('users'));
    }

    /**
     * نمایش فرم ساخت ادمین جدید
     */
    public function create()
    {
        $roles = Role::all();
        return view('admin.admin.create', compact('roles'));
    }

    /**
     * ذخیره اطلاعات ادمین جدید
     */
    public function store(Request $request)
    {
        $request->validate([
            'name'     => 'required|max:50',
            'roles'    => 'required',
            'email'    => 'required|max:100|email|unique:users',
            'password' => 'required|min:6|confirmed',
        ]);

        $user = new User();
        $user->name     = $request->name;
        $user->email    = $request->email;
        $user->role     = 'admin';
        $user->password = Hash::make($request->password);
        $user->save();

        if ($request->roles) {
            $user->assignRole($request->roles);
        }

        return response()->json([
            'redirect' => route('admin.admin.index'),
            'message'  => 'ادمین با موفقیت ایجاد شد.',
        ]);
    }

    /**
     * نمایش فرم ویرایش ادمین
     */
    public function edit($id)
    {
        $user  = User::find($id);
        $roles = Role::all();
        return view('admin.admin.edit', compact('user', 'roles'));
    }

    /**
     * به‌روزرسانی اطلاعات ادمین
     */
    public function update(Request $request, $id)
    {
        $user = User::find($id);

        $request->validate([
            'name'     => 'required|max:50',
            'email'    => 'required|max:100|email|unique:users,email,' . $id,
            'password' => 'nullable|min:6|confirmed',
        ]);

        $user->name   = $request->name;
        $user->email  = $request->email;
        $user->status = $request->status;

        if ($request->password) {
            $user->password = Hash::make($request->password);
        }

        $user->save();

        // حذف نقش‌های قبلی و تعیین نقش‌های جدید
        $user->roles()->detach();
        if ($request->roles) {
            $user->assignRole($request->roles);
        }

        return response()->json([
            'message' => 'اطلاعات ادمین با موفقیت به‌روزرسانی شد.',
        ]);
    }

    /**
     * حذف یک ادمین
     */
    public function destroy($id)
    {
        User::destroy($id);

        return response()->json([
            'redirect' => route('admin.admin.index'),
            'message'  => 'ادمین با موفقیت حذف شد.',
        ]);
    }
}
