@extends('layouts.main.app')

@section('head')
@include('layouts.main.headersection',[
'title'=> __('ویرایش درگاه پرداخت'),
'buttons'=>[
[
'name'=>__('بازگشت'),
'url'=>route('admin.gateways.index'),
]
]
])
@endsection

@section('content')
<div class="row">
	<div class="col-lg-5 mt-5">
		<strong>{{ __('ویرایش اطلاعات درگاه') }}</strong>
		<p>{{ __('از این بخش می‌توانید اطلاعات درگاه پرداخت را ویرایش کنید.') }}</p>
	</div>
	<div class="col-lg-7 mt-5">
		<form class="ajaxform_instant_reload" action="{{ route('admin.gateways.update', $gateway->id) }}" enctype="multipart/form-data" method="POST">
			@csrf
			@method('PUT')
			<div class="card">
				<div class="card-body">

					<div class="form-group mb-4">
						<label class="col-form-label required" for="name">{{ __('عنوان درگاه') }}</label>
						<input type="text" class="form-control" name="name" id="name" value="{{ $gateway->name }}" required>
					</div>

					<div class="form-group mb-4">
						<label class="col-form-label" for="logo">{{ __('لوگو') }}</label>
						<input type="file" id="logo" class="form-control" name="logo" accept="image/*">
						@if ($gateway->logo)
						<img src="{{ asset($gateway->logo) }}" height="30" alt="Logo" class="image-thumbnail mt-2">
						@endif
					</div>

					<div class="form-group mb-4">
						<label class="col-form-label required" for="currency">{{ __('واحد پول') }}</label>
						<input type="text" class="form-control" name="currency" id="currency" value="{{ $gateway->currency }}" required>
					</div>

					<div class="form-group mb-4">
						<label class="col-form-label required" for="min_amount">{{ __('حداقل مبلغ تراکنش') }}</label>
						<input type="number" step="any" class="form-control" name="min_amount" id="min_amount" value="{{ $gateway->min_amount }}" required>
					</div>

					<div class="form-group mb-4">
						<label class="col-form-label required" for="max_amount">{{ __('حداکثر مبلغ تراکنش') }}</label>
						<input type="number" step="any" class="form-control" name="max_amount" id="max_amount" value="{{ $gateway->max_amount }}" required>
					</div>

					<div class="form-group mb-4">
						<label class="col-form-label required" for="charge">{{ __('کارمزد درگاه') }}</label>
						<input type="number" step="any" class="form-control" name="charge" id="charge" value="{{ $gateway->charge ?? 0 }}" required>
					</div>

					<div class="form-group mb-4">
						<label class="col-form-label required" for="multiply">{{ __('ضریب تبدیل واحد پول') }}</label>
						<input type="number" step="any" class="form-control" name="multiply" id="multiply" value="{{ $gateway->multiply ?? 0 }}" required>
						<small class="text-muted d-block mt-1">برای تبدیل تومان به ریال عدد ۱۰ وارد کنید</small>
					</div>

					@php
					$data = json_decode($gateway->data ?? '{}', true);
					@endphp

					<div class="form-group mb-4">
						<label class="col-form-label required" for="merchant_id">{{ __('کلید API / مرچنت کد') }}</label>
						<input type="text" class="form-control" name="data[merchant_id]" id="merchant_id" value="{{ $data['merchant_id'] ?? '' }}" placeholder="مثال: zarinpal-xxxx-xxxx">
						<small class="text-muted d-block mt-1">این مقدار برای زرین‌پال، Pay.ir، IdPay و سایر درگاه‌های پیامکی استفاده می‌شود.</small>
					</div>

					<div class="form-group mb-4">
						<label class="col-form-label required" for="sandbox">{{ __('حالت تستی (Sandbox Mode)') }}</label>
						<select class="form-control selectric" name="data[test_mode]" id="sandbox">
							<option value="1" {{ ($data['test_mode'] ?? 0) == 1 ? 'selected' : '' }}>{{ __('فعال') }}</option>
							<option value="0" {{ ($data['test_mode'] ?? 0) == 0 ? 'selected' : '' }}>{{ __('غیرفعال') }}</option>
						</select>
						<small class="text-muted mt-1 d-block">اگر درگاه شما از حالت تستی پشتیبانی می‌کند، این گزینه را فعال کنید.</small>
					</div>

					<div class="form-group mb-4">
						<label class="col-form-label" for="comment">{{ __('راهنمای پرداخت') }}</label>
						<textarea class="form-control" maxlength="1000" name="comment" rows="3">{{ $gateway->comment }}</textarea>
					</div>

					<div class="form-group mb-4">
						<label class="col-form-label required" for="status">{{ __('وضعیت درگاه') }}</label>
						<select class="form-control selectric" name="status" id="status">
							<option value="1" {{ $gateway->status == 1 ? 'selected' : '' }}>{{ __('فعال') }}</option>
							<option value="0" {{ $gateway->status == 0 ? 'selected' : '' }}>{{ __('غیرفعال') }}</option>
						</select>
					</div>

					<div class="form-group mb-4">
						<button class="btn btn-neutral submit-button">{{ __('ذخیره تغییرات') }}</button>
					</div>

				</div>
			</div>
		</form>
	</div>
</div>
@endsection