@extends('layouts.main.app')

@section('head')
@include('layouts.main.headersection',[
'title'=> __('درگاه‌های پرداخت'),
'buttons'=>[
[
'name'=>'<i class="fa fa-plus"></i>&nbsp;'.__('افزودن درگاه جدید'),
'url'=>route('admin.gateways.create'),
]
]
])
@endsection

@section('content')

<div class="row d-flex justify-content-between flex-wrap">
	<div class="col">
		<div class="card card-stats">
			<div class="card-body">
				<div class="row">
					<div class="col">
						<span class="h2 font-weight-bold mb-0" id="total-gateways">{{ $totalGateways }}</span>
					</div>
					<div class="col-auto">
						<div class="icon icon-shape bg-gradient-primary text-white rounded-circle shadow">
							<i class="fi fi-rs-bank mt-2"></i>
						</div>
					</div>
				</div>
				<h5 class="card-title text-muted mb-0 mt-3">{{ __('تعداد کل درگاه‌ها') }}</h5>
			</div>
		</div>
	</div>

	<div class="col">
		<div class="card card-stats">
			<div class="card-body">
				<div class="row">
					<div class="col">
						<span class="h2 font-weight-bold mb-0" id="total-active">{{ $active_gateway }}</span>
					</div>
					<div class="col-auto">
						<div class="icon icon-shape bg-gradient-success text-white rounded-circle shadow">
							<i class="fi fi-rs-badge-check mt-2"></i>
						</div>
					</div>
				</div>
				<h5 class="card-title text-muted mb-0 mt-3">{{ __('درگاه‌های فعال') }}</h5>
			</div>
		</div>
	</div>

	<div class="col">
		<div class="card card-stats">
			<div class="card-body">
				<div class="row">
					<div class="col">
						<span class="h2 font-weight-bold mb-0" id="total-inactive">{{ $inactive_gateway }}</span>
					</div>
					<div class="col-auto">
						<div class="icon icon-shape bg-gradient-danger text-white rounded-circle shadow">
							<i class="fi fi-rs-delete-document mt-2"></i>
						</div>
					</div>
				</div>
				<h5 class="card-title text-muted mb-0 mt-3">{{ __('درگاه‌های غیرفعال') }}</h5>
			</div>
		</div>
	</div>
</div>

<div class="row mt-4">
	<div class="col">
		<div class="card">
			<div class="card-header border-0">
				<h3 class="mb-0">{{ __('لیست درگاه‌ها') }}</h3>
			</div>
			<div class="table-responsive">
				<table class="table align-items-center table-flush">
					<thead class="thead-light">
						<tr>
							<th>{{ __('نام درگاه') }}</th>
							<th class="text-center">{{ __('حداقل مبلغ') }}</th>
							<th class="text-center">{{ __('حداکثر مبلغ') }}</th>
							<th class="text-center">{{ __('کارمزد') }}</th>
							<th class="text-center">{{ __('واحد پول') }}</th>
							<th class="text-center">{{ __('وضعیت') }}</th>
							<th class="text-center">{{ __('حالت پرداخت') }}</th>
							<th class="text-center">{{ __('ویرایش') }}</th>
						</tr>
					</thead>
					<tbody class="list">
						@foreach($gateways as $gateway)
						@php $data = json_decode($gateway->data ?? '{}', true); @endphp
						<tr>
							<td>
								<div class="media align-items-center">
									@if($gateway->logo)
									<a href="{{ route('admin.gateways.edit',$gateway->id) }}" class="avatar rounded-square mr-3">
										<img alt="Logo" src="{{ asset($gateway->logo) }}">
									</a>
									@endif
									<div class="media-body">
										<span class="name mb-0 text-sm d-block font-weight-bold">{{ $gateway->name }}</span>
										@if(!empty($data['merchant_id']))
										<small class="text-muted d-block">ID: {{ $data['merchant_id'] }}</small>
										@endif
									</div>
								</div>
							</td>

							<td class="text-center">{{ number_format($gateway->min_amount, 2) }}</td>
							<td class="text-center">{{ number_format($gateway->max_amount, 2) }}</td>
							<td class="text-center">{{ $gateway->charge }} {{ strtoupper($gateway->currency) }}</td>
							<td class="text-center">{{ strtoupper($gateway->currency) }}</td>

							<td class="text-center">
								<span class="badge badge-dot">
									<i class="bg-{{ $gateway->status == 1 ? 'success' : 'danger' }}"></i>
									<span class="status">{{ $gateway->status == 1 ? __('فعال') : __('غیرفعال') }}</span>
								</span>
							</td>

							<td class="text-center">
								<span class="badge badge-dot">
									<i class="bg-{{ ($data['test_mode'] ?? 0) == 1 ? 'danger' : 'success' }}"></i>
									<span class="status">{{ ($data['test_mode'] ?? 0) == 1 ? __('تستی') : __('واقعی') }}</span>
								</span>
							</td>

							<td class="text-center">
								<a class="btn btn-sm btn-neutral" href="{{ route('admin.gateways.edit',$gateway->id) }}">
									<i class="fas fa-edit"></i>
								</a>
							</td>
						</tr>
						@endforeach
					</tbody>
				</table>
			</div>
		</div>
	</div>
</div>

@endsection